package cn.com.infosec.crypto.paddings;

import cn.com.infosec.crypto.BlockCipher;
import cn.com.infosec.crypto.BufferedBlockCipher;
import cn.com.infosec.crypto.CipherParameters;
import cn.com.infosec.crypto.DataLengthException;
import cn.com.infosec.crypto.params.ParametersWithRandom;
import java.security.SecureRandom;

public class PaddedBufferedBlockCipher extends BufferedBlockCipher {
   BlockCipherPadding padding;

   public PaddedBufferedBlockCipher(BlockCipher cipher, BlockCipherPadding padding) {
      super.cipher = cipher;
      this.padding = padding;
      super.buf = new byte[cipher.getBlockSize()];
      super.bufOff = 0;
   }

   public PaddedBufferedBlockCipher(BlockCipher cipher) {
      PaddedBufferedBlockCipher var10000 = this;
      PKCS7Padding var2;
      var2 = new PKCS7Padding.<init>();
      var10000.<init>(cipher, var2);
   }

   public void init(boolean forEncryption, CipherParameters params) {
      super.forEncryption = forEncryption;
      this.reset();
      if (params instanceof ParametersWithRandom) {
         PaddedBufferedBlockCipher var10000 = this;
         PaddedBufferedBlockCipher var10001 = this;
         ParametersWithRandom var3 = (ParametersWithRandom)params;
         var10001.padding.init(var3.getRandom());
         var10000.cipher.init(forEncryption, var3.getParameters());
      } else {
         this.padding.init((SecureRandom)null);
         super.cipher.init(forEncryption, params);
      }

   }

   public int getOutputSize(int len) {
      byte[] var2;
      int var3;
      if ((var3 = (len += super.bufOff) % (var2 = super.buf).length) == 0) {
         return super.forEncryption ? len + var2.length : len;
      } else {
         return len - var3 + var2.length;
      }
   }

   public int getUpdateOutputSize(int len) {
      int var2;
      byte[] var3;
      return (var2 = (len += super.bufOff) % (var3 = super.buf).length) == 0 ? len - var3.length : len - var2;
   }

   public int processByte(byte in, byte[] out, int outOff) {
      int var4 = 0;
      byte[] var5;
      if (super.bufOff == (var5 = super.buf).length) {
         var4 = super.cipher.processBlock(var5, 0, out, outOff);
         super.bufOff = 0;
      }

      byte[] var10001 = super.buf;
      int var6;
      super.bufOff = (var6 = super.bufOff) + 1;
      var10001[var6] = in;
      return var4;
   }

   public int processBytes(byte[] in, int inOff, int len, byte[] out, int outOff) {
      if (len >= 0) {
         int var6 = this.getBlockSize();
         int var7;
         if ((var7 = this.getUpdateOutputSize(len)) > 0 && outOff + var7 > out.length) {
            throw new DataLengthException("output buffer too short");
         } else {
            byte var12 = 0;
            byte[] var8;
            int var9;
            int var10;
            int var10000;
            if (len > (var10 = (var8 = super.buf).length - (var9 = super.bufOff))) {
               var10000 = inOff;
               System.arraycopy(in, inOff, var8, var9, var10);
               inOff = super.cipher.processBlock(super.buf, 0, out, outOff) + var12;
               super.bufOff = 0;
               len -= var10;

               for(var7 = var10000 + var10; len > super.buf.length; var7 += var6) {
                  int var10004 = inOff;
                  inOff += outOff;
                  inOff = var10004 + super.cipher.processBlock(in, var7, out, inOff);
                  len -= var6;
               }
            } else {
               var10000 = inOff;
               inOff = var12;
               var7 = var10000;
            }

            PaddedBufferedBlockCipher var10001 = this;
            PaddedBufferedBlockCipher var10002 = this;
            PaddedBufferedBlockCipher var10005 = this;
            byte[] var11 = super.buf;
            System.arraycopy(in, var7, var11, var10005.bufOff, len);
            var10001.bufOff = var10002.bufOff + len;
            return inOff;
         }
      } else {
         throw new IllegalArgumentException("Can't have a negative input length!");
      }
   }

   public int doFinal(byte[] out, int outOff) {
      Throwable var14;
      label112: {
         int var3 = super.cipher.getBlockSize();
         int var4 = 0;
         if (super.forEncryption) {
            if (super.bufOff == var3) {
               if (outOff + var3 * 2 > out.length) {
                  this.reset();
                  throw new DataLengthException("output buffer too short");
               }

               var4 = super.cipher.processBlock(super.buf, 0, out, outOff);
               super.bufOff = 0;
            }

            PaddedBufferedBlockCipher var10000 = this;
            byte[] var13 = super.buf;
            this.padding.addPadding(var13, super.bufOff);
            BlockCipher var10002 = super.cipher;
            byte[] var11 = super.buf;
            outOff += var4;
            int var12 = var4 + var10002.processBlock(var11, 0, out, outOff);
            var10000.reset();
            var3 = var12;
         } else {
            if (super.bufOff != var3) {
               this.reset();
               throw new DataLengthException("last block incomplete in decryption");
            }

            PaddedBufferedBlockCipher var10001 = this;
            byte[] var10003 = super.buf;
            int var16 = super.cipher.processBlock(var10003, 0, var10003, 0);
            PaddedBufferedBlockCipher var17 = this;
            super.bufOff = 0;

            boolean var15;
            int var18;
            try {
               var18 = var17.padding.padCount(super.buf);
            } catch (Throwable var10) {
               var14 = var10;
               var15 = false;
               break label112;
            }

            var3 = var16 - var18;

            try {
               System.arraycopy(var10001.buf, 0, out, outOff, var3);
            } catch (Throwable var9) {
               var14 = var9;
               var15 = false;
               break label112;
            }

            this.reset();
         }

         return var3;
      }

      this.reset();
      throw var14;
   }
}
